@@ -3,8 +3,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_HELPER_H
-#define EVENTVIEWS_HELPER_H
+#pragma once
 
 #include "eventviews_export.h"
 
@@ -75,7 +74,7 @@ EVENTVIEWS_EXPORT void setResourceColor(const Akonadi::Collection &collection, c
   Returns the number of years between the @p start QDate and the @p end QDate
   (i.e. the difference in the year number of both dates)
 */
-Q_REQUIRED_RESULT int yearDiff(const QDate &start, const QDate &end);
+Q_REQUIRED_RESULT int yearDiff(QDate start, QDate end);
 
 /**
    Equivalent to SmallIcon( name ), but uses QPixmapCache.
@@ -87,4 +86,3 @@ Q_REQUIRED_RESULT int yearDiff(const QDate &start, const QDate &end);
 Q_REQUIRED_RESULT QPixmap cachedSmallIcon(const QString &name);
 }
 
-#endif
