@@ -21,10 +21,10 @@
 #include "todoviewsortfilterproxymodel.h"
 #include "todoviewview.h"
 
-#include <AkonadiCore/EntityMimeTypeFilterModel>
-#include <AkonadiCore/TagFetchJob>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/TagFetchJob>
 
-#include <AkonadiWidgets/ETMViewStateSaver>
+#include <Akonadi/ETMViewStateSaver>
 
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
@@ -41,6 +41,9 @@
 #include <QIcon>
 #include <QMenu>
 #include <QToolButton>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 Q_DECLARE_METATYPE(QPointer<QMenu>)
 
@@ -142,7 +145,7 @@ public:
         return todoFlatModel != nullptr;
     }
 
-    TodoModel *todoModel = nullptr;
+    TodoModel *const todoModel;
     QList<TodoView *> views;
     QObject *parent = nullptr;
 
@@ -166,7 +169,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 {
     mResizeColumnsTimer = new QTimer(this);
     connect(mResizeColumnsTimer, &QTimer::timeout, this, &TodoView::resizeColumns);
-    mResizeColumnsTimer->setInterval(100); // so we don't overdue it when user resizes window manually
+    mResizeColumnsTimer->setInterval(100ms); // so we don't overdue it when user resizes window manually
     mResizeColumnsTimer->setSingleShot(true);
 
     setPreferences(prefs);
@@ -186,7 +189,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     if (!mSidebarView) {
         mQuickSearch = new TodoViewQuickSearch(calendar(), this);
         mQuickSearch->setVisible(prefs->enableTodoQuickSearch());
-        connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged, mProxyModel, QOverload<const QString &>::of(&QSortFilterProxyModel::setFilterRegExp));
+        connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged, mProxyModel, qOverload<const QString &>(&QSortFilterProxyModel::setFilterRegExp));
         connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged, this, &TodoView::restoreViewState);
         connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, mProxyModel, &TodoViewSortFilterProxyModel::setCategoryFilter);
         connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, this, &TodoView::restoreViewState);
@@ -519,6 +522,7 @@ void TodoView::restoreLayout(KConfig *config, const QString &group, bool minimal
         mView->hideColumn(TodoModel::RecurColumn);
         mView->hideColumn(TodoModel::DescriptionColumn);
         mView->hideColumn(TodoModel::CalendarColumn);
+        mView->hideColumn(TodoModel::CompletedDateColumn);
 
         if (minimalDefaults) {
             mView->hideColumn(TodoModel::PriorityColumn);
@@ -933,11 +937,7 @@ void TodoView::setNewPercentage(QAction *action)
         } else {
             todo->setPercentComplete(percentage);
         }
-        if (todo->recurs() && percentage == 100) {
-            changer()->modifyIncidence(todoItem, oldTodo, this);
-        } else {
-            changer()->modifyIncidence(todoItem, oldTodo, this);
-        }
+        changer()->modifyIncidence(todoItem, oldTodo, this);
     } else {
         qCDebug(CALENDARVIEW_LOG) << "Item is read only";
     }
@@ -1093,6 +1093,7 @@ void TodoView::resizeColumns()
 
     mView->resizeColumnToContents(TodoModel::StartDateColumn);
     mView->resizeColumnToContents(TodoModel::DueDateColumn);
+    mView->resizeColumnToContents(TodoModel::CompletedDateColumn);
     mView->resizeColumnToContents(TodoModel::PriorityColumn);
     mView->resizeColumnToContents(TodoModel::CalendarColumn);
     mView->resizeColumnToContents(TodoModel::RecurColumn);
